""" CLI timer for working with the pomodoro method """
import click
import toml
import os
import sched
import time

from pomme.timer import Timer

file_path = os.path.dirname(__file__)
config = toml.load(os.path.join(file_path, "config.toml"))

database_location = config['database']['location']

timer = Timer(database_location)


@click.command()
def cancel() -> None:
    """ stop timer """
    timer.cancel()


@click.command()
@click.argument(
   'duration'
)
def start(duration: str) -> None:
    """ start timer

    Format of the duration can be either hh:mm:ss, mm:ss or mm

    :param duration: duration of the timer
    """
    print("timer start")
    timer.start(duration)

    # TODO: abstract this behavior in a function/class besause it's awefull
    # TODO: add the stopping condition
    s = sched.scheduler(time.time, time.sleep)
    s.enter(1, 1, print_time, (s,))
    s.run()


def print_time(s) -> None:
    """
    :param s: sheduler
    """
    if timer.running():
        print(timer.remaining())
    else:
        print("timer finished")
        return
    s.enter(1, 1, print_time, (s,))


@click.group()
def pomme() -> None:
    """ main command """
    pass


pomme.add_command(start)
pomme.add_command(cancel)
